@@ -27,4 +27,11 @@ int main()
     cp.push_back(6);
     cout << cp.size() << ' ' << cp.front() << ' ' << cp.back() << '\n';
 }
+
+/*
+    Displays:
+        5 1 5
+        3 3 5
+        4 3 6
+*/
 //=
