@@ -2,11 +2,11 @@
 //CHILD
     void Monitor::processChild(int fd)
     {
-        ifdstreambuf ifdbuf(fd);
+        IFdStreambuf ifdbuf(fd);
         istream istr(&ifdbuf);
         string line;
 
         getline(istr, line);
-        cout << d_child[fd]->pid() << ": " << line << endl;
+        cout << d_child[fd]->pid() << ": " << line << '\n';
     }
 //=
