@@ -1,5 +1,5 @@
-#ifndef _INCLUDED_CHILDPROCESS_H_
-#define _INCLUDED_CHILDPROCESS_H_
+#ifndef INCLUDED_CHILDPROCESS_H_
+#define INCLUDED_CHILDPROCESS_H_
 
 namespace FBB
 {
