@@ -7,8 +7,8 @@ int main()
 {
     list<string> object;
 
-    object.push_front(string("Hello"));
-    object.push_back(string("World"));
+    object.push_front("Hello"s);
+    object.push_back("World"s);
 
     list<string> argument(object);
 
