@@ -9,12 +9,11 @@
     {
         string words[] =
             { "kilo", "alpha", "lima", "mike", "alpha", "november", "alpha",
-                "oscar", "alpha", "alpha", "papa", "quebec" };
+                "oscar", "alpha", "alpha", "papa"};
         size_t const size = sizeof(words) / sizeof(string);
 
         replace_if(words, words + size,
-                   bind1st(equal_to<string>(), string("alpha")),
-                   string("ALPHA"));
+                   bind1st(equal_to<string>(), "alpha"s), "ALPHA"s);
         copy(words, words + size, ostream_iterator<string>(cout, " "));
         cout << '\n';
     }
