@@ -40,16 +40,19 @@
                 Pss("Hampson",   "Eugene")
         };
 
-        sort(namecity.begin(), namecity.end(), Sortby(&Pss::first));// 6
+        sort(namecity.begin(), namecity.end(), Sortby{ &Pss::first });// 6
 
         cout << "sorted by names:\n";
-        copy(namecity.begin(), namecity.end(), ostream_iterator<Pss>(cout));
+        copy(namecity.begin(), namecity.end(),
+                                            ostream_iterator<Pss>{ cout });
 
                                                                     // 7
-        stable_sort(namecity.begin(), namecity.end(), Sortby(&Pss::second));
+        stable_sort(namecity.begin(), namecity.end(),
+                                            Sortby{ &Pss::second });
 
         cout << "sorted by names within sorted cities:\n";
-        copy(namecity.begin(), namecity.end(), ostream_iterator<Pss>(cout));
+        copy(namecity.begin(), namecity.end(),
+                                            ostream_iterator<Pss>{ cout });
     }
     /*
         Displays:
