@@ -1,7 +1,5 @@
     #include <iostream>
-    #include <string>
     #include <sstream>
-
     using namespace std;
 
     int main()
@@ -11,13 +9,13 @@
 
         istr.seekg(2);              // skip "12"
         istr >> x;                  // extract int
-        cout << x << endl;          // write it out
+        cout << x << '\n';          // write it out
         istr.seekg(0);              // retry from the beginning
         istr >> x;                  // extract int
-        cout << x << endl;          // write it out
+        cout << x << '\n';          // write it out
         istr.str("666");            // store another text
         istr >> x;                  // extract it
-        cout << x << endl;          // write it out
+        cout << x << '\n';          // write it out
     }
     /*
         output of this program:
