@@ -5,4 +5,6 @@
         d_capacity(tmp.d_capacity)
     {
         tmp.d_string = 0;
+        tmp.d_size = 0;
+        tmp.d_capacity = 0;
     }
