@@ -5,7 +5,7 @@
         d_size(size)
     {
         if (d_size < 1)
-            throw string("IntArray: size of array must be >= 1");
+            throw "IntArray: size of array must be >= 1"s;
 
         d_data = new int[d_size];
     }
