@@ -7,7 +7,7 @@
     int main(int argc, char **argv)
     {
         string result =
-                accumulate(argv, argv + argc, string(), plus<string>());
+                accumulate(argv, argv + argc, string{}, plus<string>());
 
         cout << "All concatenated arguments: " << result << '\n';
     }
