@@ -17,9 +17,9 @@ struct Move
 //typedef unique_ptr<int> up;
 int main()
 {
-    unique_ptr<ifstream> ip(new ifstream("hi"));
-    unique_ptr<ifstream> ip2(move(ip));
+    unique_ptr<ifstream> ip{ new ifstream{ "hi" } };
+    unique_ptr<ifstream> ip2{ move(ip) };
 
-    unique_ptr<Move> ip3(new Move);
-    unique_ptr<Move> ip4(move(ip3));
+    unique_ptr<Move> ip3{ new Move };
+    unique_ptr<Move> ip4{ move(ip3) };
 }
