@@ -15,7 +15,7 @@ void threadFun(std::string const &text)
 std::thread safeLocal()
 {
     std::string text = "hello world";
-    return std::thread(threadFun, std::string(text));
+    return std::thread(threadFun, std::string{ text });
 }
 
 int main()
